Strings
:::::::

.. toctree::
   :caption: Strings
   :maxdepth: 2

   StringsRevisited.rst
   ACollectionDataType.rst
   OperationsonStrings.rst
   IndexOperatorWorkingwiththeCharactersofaString.rst
   StringMethods.rst
   Length.rst
   TheSliceOperator.rst
   StringComparison.rst
   StringsareImmutable.rst
   TraversalandtheforLoopByItem.rst
   TraversalandtheforLoopByIndex.rst
   TraversalandthewhileLoop.rst
   Theinandnotinoperators.rst
   TheAccumulatorPatternwithStrings.rst
   TurtlesandStringsandLSystems.rst
   Loopingandcounting.rst
   Afindfunction.rst
   Optionalparameters.rst
   Characterclassification.rst
   Summary.rst
   Glossary.rst
   Exercises.rst
